@@ -319,6 +319,19 @@ navbarPage(title = div(
               <img src="https://flavjack.github.io/inti/img/tarpuy.png" style="height:80px" title="tarpuy"></a>
               <span style="display:block;"><small>Tarpuy</small></span>
               </p></div>
+              </div>
+                    '),
+              
+              br(),
+              
+              HTML('
+              <div id=footer style="width:100%; margin:auto;">
+              <div style="display:inline-block; width:100%">
+              <p style="text-align:center">
+              <a target="_blank" href="https://huito.inkaverse.com/">
+              <img src="https://huito.inkaverse.com/logo.png" style="height:80px" title="huito"></a>
+              <span style="display:block;"><small>Huito</small></span>
+              </p></div>
               </div>
                     ')
 
